package de.intevation.gnv.raster;

import java.util.HashMap;

import java.lang.ref.SoftReference;

/**
 * @author Sascha L. Teichmann (sascha.teichmann@intevation.de)
 */
public class PaletteManager
{
    protected Palette base;

    protected String  description;
    protected String  name;

    protected HashMap<Integer, SoftReference<Palette>> levels;

    public PaletteManager() {
    }

    public PaletteManager(
        String  name,
        String  description,
        Palette base
    ) {
        this.name        = name;
        this.description = description;
        this.base        = base;
        levels = new HashMap<Integer, SoftReference<Palette>>();
    }

    public String getDescription() {
        return description;
    }

    public Palette getLevel(int n) {
        if (n < 2) {
            return base;
        }

        Integer N = Integer.valueOf(n);

        Palette palette;

        synchronized (levels) {
            SoftReference<Palette> ref = levels.get(N);

            if (ref != null && (palette = ref.get()) != null) {
                return palette;
            }

            palette = base.subdivide(n);

            ref = new SoftReference(palette);

            levels.put(N, ref);
        }

        return palette;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
